/*
 * Copyright (c) 2008 Jiri Svoboda
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 * - The name of the author may not be used to endorse or promote products
 *   derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/** @addtogroup debug
 * @{
 */
/** @file
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <bool.h>

#include "cmd.h"

static void cmd_break(int argc, char *argv[]);
void	    cmd_help(int argc, char *argv[]);
static void cmd_quit(int argc, char *argv[]);

volatile bool quit = false;

cmd_desc_t cmd_table[] = {
	{ 1,	"break",	cmd_break },
	{ 0,	"help",		cmd_help },
	{ 0,	"quit",		cmd_quit },
	{ -1,	NULL,		NULL }
};

static void cmd_break(int argc, char *argv[])
{
	uintptr_t addr;

	(void)argc;
	addr = strtoul(argv[1], NULL, 0);

	printf("You requested a breakpoint at 0x%x\n", addr);
}

void cmd_help(int argc, char *argv[])
{
	int i;

	(void)argc; (void)argv;
	i = 0;
	while (cmd_table[i].name != NULL) {
		printf("%s\n", cmd_table[i].name);
		++i;
	}
}

static void cmd_quit(int argc, char *argv[])
{
	(void)argc; (void)argv;
	quit = true;
}

/** @}
 */
